============ Useful Links ============ * |source| * |pypi-usefullink| * |condaforge-usefullink| * |rtfd-usefullink| * |rtfd-alt| * |binder-usefullink| * |changelog-usefullink| .. |source| raw:: html Source - https://github.com/lsys/lexicalrichness .. |pypi-usefullink| raw:: html PyPI - https://pypi.org/project/lexicalrichness .. |condaforge-usefullink| raw:: html conda-forge - https://github.com/conda-forge/lexicalrichness-feedstock .. |rtfd-usefullink| raw:: html ReadTheDocs - https://lexicalrichness.rtfd.io .. |rtfd-alt| raw:: html Self-hosted Docs .. |binder-usefullink| raw:: html Binder - Jupyter notebook on the cloud .. |changelog-usefullink| raw:: html Releases & changelogs